<?php

namespace App;

use Illuminate\Database\Eloquent\Model;

class FoodItem extends Model
{
    protected $fillable = ['name', 'description', 'food_type', 'image', 'price', 'restaurant_id', 'menu_section_id', 'deal','peparationtime','calories','alergyinfo','spice'];


    //
    public function restaurant()
    {
        return $this->belongsTo(Restaurant::class, 'restaurant_id');
    }

    public function section()
    {
        return $this->belongsTo(foodSection::class, 'menu_section_id');
    }

    public function type()
    {
        return $this->belongsTo(FoodCategory::class, 'food_type');
    }


    public function variations()
    {
        return $this->hasMany(FoodVariation::class, 'food_item_id');
    }

    public function scopeActive($query)
    {
        return $query->where('active', 1);
    }

    public function storeVariations($variations)
    {
        foreach ($variations as $variation) {
            if (!$variation->title)
                continue;
            $foodVariation = new FoodVariation();
            $foodVariation->title = $variation->title;
            $foodVariation->min = $variation->min;
            $foodVariation->max = $variation->max;
            $foodVariation->type = $variation->mandatory ? 'MAND' : 'OPT';
            $foodVariation->food_item_id = $this->id;
            $foodVariation->save();
            $foodVariation->storeOptions($variation->options);
        }
    }

    public function setActiveStatus($value)
    {
        $this->active = $value;
        $this->save();
        return $this;


    }

}
