<?php

namespace App\Http\Controllers\Api;

use App\Cuisine;
use App\Mail\MerchantCreated;
use App\Mail\Waiter;
use App\Restaurant;
use App\RestCategory;
use App\User;
use App\Feedback;
use App\Waitercall;
use Hash;
use App\FoodCategory;
use App\FoodItem;
use App\foodSection;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;
use phpDocumentor\Reflection\DocBlock\Tags\Uses;
use Yajra\DataTables\DataTables;
use App\Http\Controllers\Controller;


class RegistermerchantController extends Controller
{

    public function registerMerchant(Request $request)
    {

        try {

          $validator = Validator::make($request->all(), [
              'merchantEmail' => 'unique:users,email',
          ]);

          if ($validator->fails()) {
            return response()->json(array('error' => true, 'message' => "Field required missing"));

          }


          $request_data = $request->all();
          //dd($request_data);
          $restaurant = Restaurant::create($request_data);

          if ($request->hasFile('image'))
              $restaurant->image = prospiral_store_file($request->image, "images/restaurant/logos");

          if ($request->hasFile('header_image'))
              $restaurant->header_image = prospiral_store_file($request->header_image, "images/restaurant/header_images");

          $restaurant->store_acronym();

          $restaurant->save();
          $restaurant->cuisines()->attach($request->cuisines);
          $restaurant->categories()->attach($request->restaurantCategories);

  //        $user = new


          try {
              $user = new User();
              $user->name = $request->merchantName;
              $user->email = $request->merchantEmail;
              $password = Str::random(8);
              $user->password = bcrypt($password);
              $user->restaurant_id = $restaurant->id;
              $user->save();

             Mail::to($user->email)->send(new MerchantCreated($user, $password));

              return response()->json(array('error' => false, 'message' => 'record stored successfully', 'restaurant'=>$restaurant,'user'=>$user));

          } catch (Exception $exception) {
              dd($exception);
          }




        } catch (\Exception $e) {
            return response()->json(array('error' => true, 'message' => $e->getMessage()));
        }
    }



    public function loginMerchant(Request $request)
    {


        try {

          $validator = Validator::make($request->all(), [
              'merchantEmail' => 'required',
              'merchantPassword' => 'required',
          ]);

          if ($validator->fails()) {
                return response()->json(array('error' => true, 'message' => "Field required missing"));
          }
          $user = User::where('email',$request->merchantEmail)->first();

          if($user)
          {
            if($user->login_check < $user->login_period)
            {
              if (Hash::check($request->merchantPassword, $user->password)) {
                $user->login_check = $user->login_check+1;
                $user->save();

                //$restaurant = new Restaurant();
                $restaurant = Restaurant::where('id', $user->restaurant_id)->first();
                return response()->json(array('error' => false, 'user' => $user, 'restaurant' => $restaurant));
              }
              else{
                return response()->json(array('error' => true, 'message' => "invalid passsword"));
              }
            }
            else{
                return response()->json(array('error' => true, 'message' => "logged in from 4 devices"));
            }
          }
          else{
              return response()->json(array('error' => true, 'message' => "No User Found"));
          }



        } catch (\Exception $e) {
            return response()->json(array('error' => true, 'message' => $e->getMessage()));
        }
    }



    public function logoutMerchant(Request $request)
    {


        try {

          $validator = Validator::make($request->all(), [
              'user_id' => 'required',

          ]);

          if ($validator->fails()) {
                return response()->json(array('error' => true, 'message' => "Field required missing"));
          }
          $user = User::where('id',$request->user_id)->first();

          if($user)
          {
            if($user->login_check != 0)
            {
                $user->login_check = $user->login_check-1;
                $user->save();

              }
                return response()->json(array('error' => false, 'message' => "logout successfully"));
            }
          else{
              return response()->json(array('error' => true, 'message' => "No User Found"));
          }

        } catch (\Exception $e) {
            return response()->json(array('error' => true, 'message' => $e->getMessage()));
        }
    }


    public function reviewFeddback(Request $request)
    {


        try {

          $validator = Validator::make($request->all(), [
              'restaurant_id' => 'required',
              'name' => 'required',
              'email' => 'required',
              'subject' => 'required',
              'message' => 'required',

          ]);

          if ($validator->fails()) {
                return response()->json(array('error' => true, 'message' => "Field required missing"));
          }


          $feedback = new Feedback();
          $feedback->name = $request->name;
          $feedback->email = $request->email;
          $feedback->subject = $request->subject;
          $feedback->message = $request->message;
          $feedback->restaurant_id = $request->restaurant_id;
          $feedback->save();

          return response()->json(array('error' => false, 'message' => "Feedback submited  successfully"));

        } catch (\Exception $e) {
            return response()->json(array('error' => true, 'message' => $e->getMessage()));
        }
    }


    public function waiterCall(Request $request)
    {


        try {

          $validator = Validator::make($request->all(), [
              'restaurant_id' => 'required',
              'tableno' => 'required',


          ]);

          if ($validator->fails()) {
                return response()->json(array('error' => true, 'message' => "Field required missing"));
          }


          $call = new Waitercall();
          $call->restaurant_id = $request->restaurant_id;
          $call->tableno = $request->tableno;

          $call->save();
          
          $emailres = Restaurant::where('id',$request->restaurant_id)->first();
          Mail::to($emailres->callemail)->send(new Waiter($request->tableno));
          return response()->json(array('error' => false, 'message' => "waitercall submited  successfully"));

        } catch (\Exception $e) {
            return response()->json(array('error' => true, 'message' => $e->getMessage()));
        }
    }


    public function menus(Request $request)
    {


        try {

          $validator = Validator::make($request->all(), [
              'restaurant_id' => 'required',



          ]);

          if ($validator->fails()) {
                return response()->json(array('error' => true, 'message' => "Field required missing"));
          }


          $menu = FoodCategory::where('created_by',$request->restaurant_id)->get();


          return response()->json(array('error' => false, 'menu' => $menu));

        } catch (\Exception $e) {
            return response()->json(array('error' => true, 'message' => $e->getMessage()));
        }
    }

    public function sub_menus(Request $request)
    {


        try {

          $validator = Validator::make($request->all(), [
              'menu_id' => 'required',



          ]);

          if ($validator->fails()) {
                return response()->json(array('error' => true, 'message' => "Field required missing"));
          }


          $menu = FoodItem::where('food_type',$request->menu_id)->get();


          return response()->json(array('error' => false, 'menu' => $menu));

        } catch (\Exception $e) {
            return response()->json(array('error' => true, 'message' => $e->getMessage()));
        }
    }




    public function view_restaurant($restaurant)
    {


        try {

        if(!$restaurant || $restaurant == "" || $restaurant == null)
        {
          return redirect()->back();
        }


          $restaurant = Restaurant::where('name' ,$restaurant)->first();

        return view('merchant.restaurantView')->with(['restaurant'=>$restaurant]);


        } catch (\Exception $e) {
          return redirect()->back();
        }
    }

    public function restaurantcallforwaiter($restaurant)
    {


        try {

        if(!$restaurant || $restaurant == "" || $restaurant == null)
        {
          return redirect()->back();
        }


          $restaurant = Restaurant::where('name' ,$restaurant)->first();

        return view('merchant.waiterview')->with(['restaurant'=>$restaurant]);


        } catch (\Exception $e) {
          return redirect()->back();
        }
    }


    public function restaurantfeeddback($restaurant)
    {


        try {

        if(!$restaurant || $restaurant == "" || $restaurant == null)
        {
          return redirect()->back();
        }


          $restaurant = Restaurant::where('name' ,$restaurant)->first();
          
          $rew = feedback::where('restaurant_id', $restaurant->id)->where('status', "1")->get();

        return view('merchant.feedbackview')->with(['restaurant'=>$restaurant,'rew'=>$rew]);


        } catch (\Exception $e) {
          return redirect()->back();
        }
    }



    public function restaurantmenus($restaurant)
    {


        try {

        if(!$restaurant || $restaurant == "" || $restaurant == null)
        {
          return redirect()->back();
        }


          $restaurant = Restaurant::where('name' ,$restaurant)->first();
          $menu = FoodCategory::where('created_by',$restaurant->id)->get();

        return view('merchant.menuview')->with(['restaurant'=>$restaurant,'menu'=>$menu]);


        } catch (\Exception $e) {
          return redirect()->back();



        }
    }

    public function restaurantsubmenus($restaurant,$submenu)
    {

        try {

        if(!$restaurant || $restaurant == "" || $restaurant == null)
        {
          return redirect()->back();
        }


          $restaurant = Restaurant::where('name' ,$restaurant)->first();
          $menu = FoodItem::where('food_type',$submenu)->get();
            $submenu = FoodCategory::where('id',$submenu)->first();
        return view('merchant.submenuview')->with(['restaurant'=>$restaurant,'menu'=>$menu,'submenu'=>$submenu]);


        } catch (\Exception $e) {
          return redirect()->back();



        }
    }


    public function itemdetails($restaurant,$submenu)
    {

        try {

        if(!$restaurant || $restaurant == "" || $restaurant == null)
        {

          return redirect()->back();
        }


          $restaurant = Restaurant::where('name' ,$restaurant)->first();
          $menu = FoodItem::where('id',$submenu)->first();

          $recomended = FoodItem::where('food_type',$menu->food_type)->take(4)->get();
          $recomended = $recomended->shuffle();

        return view('merchant.itemdetails')->with(['restaurant'=>$restaurant,'menu'=>$menu,'recomended'=>$recomended]);


        } catch (\Exception $e) {
          return redirect()->back();



        }
    }




    public function restaurantfeeddbacksubmit(Request $request)
    {

        $rest = Restaurant::where('id', $request->restaurant_id)->first();

        try {

          $validator = Validator::make($request->all(), [
              'restaurant_id' => 'required',
              'name' => 'required',
              'email' => 'required',
              'subject' => 'required',
              'message' => 'required',

          ]);

          if ($validator->fails()) {
                  return redirect()->route('view.restaurant' , $rest->name);
          }


          $feedback = new Feedback();
          $feedback->name = $request->name;
          $feedback->email = $request->email;
          $feedback->subject = $request->subject;
          $feedback->message = $request->message;
          $feedback->staff = $request->staff;
          $feedback->food = $request->food;
          $feedback->service = $request->service;
          $feedback->ambience = $request->ambience;
          $feedback->restaurant_id = $request->restaurant_id;
          $feedback->save();

            return redirect()->route('view.restaurant' , $rest->name);

        } catch (\Exception $e) {
              return redirect()->route('view.restaurant' , $rest->name);
        }
    }



    public function restaurantcallforwaitersubmit(Request $request)
    {


        try {
            $rest = Restaurant::where('id', $request->restaurant_id)->first();

          $validator = Validator::make($request->all(), [
              'restaurant_id' => 'required',
              'tableno' => 'required',


          ]);

          if ($validator->fails()) {
                return redirect()->route('view.restaurant' , $rest->name);
          }


          $call = new Waitercall();
          $call->restaurant_id = $request->restaurant_id;
          $call->tableno = $request->tableno;

          $call->save();
          $emailres = Restaurant::where('id',$request->restaurant_id)->first();
Mail::to($emailres->callemail)->send(new Waiter($call->tableno));
          return redirect()->route('view.restaurant' , $rest->name);

        } catch (\Exception $e) {
          return redirect()->route('view.restaurant' , $rest->name);
        }
    }

    public function hello()
    {
      dd("df");
    }



    public function waiterreqs(Request $request)
    {


        try {


          $menu = Waitercall::where('restaurant_id',$request->name)->get();

          $view = '  <h6 class="dropdown-header">
                Notifications
            </h6> ';
            $view2 = '  <h6 class="dropdown-header">
                Notifications
            </h6> ';
            
            $count = 0;
          foreach ($menu as $m) {
            $date = date('Y-m-d H:i:s', strtotime('-12 hour'));
            $date2 = date('Y-m-d H:i:s', strtotime('-5 min'));
            $tt = date('Y-m-d H:i:s' , strtotime($m->created_at));

            if($tt > $date)
            {
          $view .= '<a class="dropdown-item d-flex align-items-center" href="#">
              <div class="mr-3">
                  <div class="icon-circle bg-warning">
                      <i class="fas fa-exclamation-triangle text-white"></i>
                  </div>
              </div>
              <div>
                  <div class="small text-gray-500">'.$m->created_at.'</div>
                  A new request from table no '.$m->tableno.'!
              </div>
          </a>';
        }
        
        if($tt > $date2)
            {
                $count++;
          $view2 .= '<a class="dropdown-item d-flex align-items-center" href="#">
              <div class="mr-3">
                  <div class="icon-circle bg-warning">
                      <i class="fas fa-exclamation-triangle text-white"></i>
                  </div>
              </div>
              <div>
                  <div class="small text-gray-500">'.$m->created_at.'</div>
                  A new request from table no '.$m->tableno.'!
              </div>
          </a>';
        }
          }



          return response()->json(array('error' => false, 'view' => $view,'view2'=>$view2,'count'=>$count));

        } catch (\Exception $e) {
            return response()->json(array('error' => true, 'message' => $e->getMessage()));
        }
    }




}
