<?php

namespace App\Http\Controllers\Api;

use App\Cuisine;
use App\FoodCategory;
use App\Http\Resources\RestaurantDetail;
use App\Restaurant;

use App\RestaurantTheme;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Response;

class restaurantController extends Controller
{
    public function getAllRestaurants(Request $request)
    {

        try {
            $restaurants = Restaurant::all();
            return response()->json(\App\Http\Resources\Restaurant::collection($restaurants));

        } catch (\Exception $exception) {
            return response()->json(array('restaurants' => [], 'error' => true, 'message' => $exception->getMessage()));

        }


    }


    public function filterRestaurants(Request $request)
    {
        try {

            $lat = $request->location['lat'];
            $lng = $request->location['lng'];
            $distance = 1;
            $cuisines = $request->cuisines;
            if ($request->cuisine) {
                $cuisine = Cuisine::where('name', $request->cuisine)->first();

                if ($cuisine)
                    array_push($cuisines, $cuisine->id);
            }


            $restaurants = Restaurant::GetByDistance($lat, $lng, $distance)->filterCuisines($cuisines)->filterCategories($request->categories)->paginate(6);


            $pagination = prospiral_paginate($restaurants);
            return response()->json(array('restaurants' => \App\Http\Resources\Restaurant::collection($restaurants), 'pagination' => $pagination, 'error' => false, 'message' => 'restaurants fetched successfully'));

        } catch (\Exception $exception) {
            return response()->json(array('error' => true, 'message' => $exception->getMessage()));
        }

    }


    public function getThemedRestaurants(Request $request)
    {

        try {

            $lat = $request->location['lat'];
            $lng = $request->location['lng'];
            $distance = 1;


            $restaurants = Restaurant::GetByDistance($lat, $lng, $distance)->filterCuisines(RestaurantTheme::where('title', str_replace('-', ' ', $request->theme))->first()->cuisines()->select('cuisines.id')->get())->filterCategories($request->categories)->paginate(6);

            $pagination = prospiral_paginate($restaurants);
            return response()->json(array('restaurants' => \App\Http\Resources\Restaurant::collection($restaurants), 'pagination' => $pagination, 'error' => false, 'message' => 'restaurants fetched successfully'));

        } catch (\Exception $exception) {
            return response()->json(array('error' => true, 'message' => $exception->getMessage()));
        }

    }


    public function show(Request $request)
    {
        try {

            $restaurant = Restaurant::where('slug', $request->slug)->first();
            if (!$restaurant)
                return response()->json(array('error' => true, 'message' => 'no restaurant found'));

            $restaurant = new RestaurantDetail($restaurant);
            return response()->json(array('restaurant' => $restaurant, 'error' => false, 'message' => 'restaurant fetched successfully'));
        } catch (\Exception  $exception) {
            return response()->json(array('error' => true, 'message' => $exception->getMessage()));
        }

    }

    public function getMenuNFoodSections(Request $request)
    {

        $restaurant = Restaurant::find($request->restaurant);

        $menuSections = $restaurant->foodSections;
        $food_categories = FoodCategory::all();
        return response()->json(array('food_sections' => $menuSections, 'food_categories' => $food_categories));

    }


    public function getLaterTimings(Request $request)
    {
        try {

            $timings = Restaurant::find($request->restaurant_id)->getLaterTimings();
            return response()->json(array('timings' => $timings, 'error' => false, 'message' => 'timings fetched successfully'));

        } catch (\Exception $exception) {
            return response()->json(array('error' => true, 'message' => $exception->getMessage()));


        }
    }

    public function checkDelivery(Request $request)
    {
        try {

            $delivery = Restaurant::find($request->restaurant_id)->measureDistance($request->lat, $request->lng) < config('location.delivery_radius');
            return response()->json(array('deliver' => $delivery, 'error' => false, 'message' => 'calculated successfully'));

        } catch (\Exception $exception) {

            return response()->json(array('deliver' => false, 'error' => true, 'message' => $exception->getMessage()));

        }
    }

}
