<?php

namespace App\Http\Controllers;

use App\FoodCategory;
use App\FoodItem;
use App\foodSection;
use App\Http\Resources\FoodVariation;
use App\Restaurant;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class FoodItemController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if (request()->ajax()) {
            return DataTables::of(FoodItem::select('id', 'name', 'active')->orderBy('id', 'desc')->get())
                ->addColumn('restaurant', function ($foodItem) {
                    $rest = FoodItem::find($foodItem->id)->restaurant;
                    if (!$rest)
                        return '---';
                    return FoodItem::find($foodItem->id)->restaurant->name;
                })->addColumn('active', function ($item) {

                    $checked = $item->active ? 'checked' : '';

                    return "<div class='custom-control custom-switch'  >
                <input type='checkbox' class='custom-control-input active-item ' data-id='$item->id'  $checked id='item-switch$item->id'  >
                 <label class='custom-control-label' for='item-switch$item->id' ></label >
                    </div > ";
                })->addColumn('action', function ($item) {
                    $edit_route = route('food-item.edit', ['foodItem' => $item->id]);
                    $delete_route = route('food-item.destroy', ['foodItem' => $item->id]);
                    $detail_route = route('food-item.show', ['foodItem' => $item->id]);

                    $del_func = "onclick = deletenow('$delete_route')";
                    return "<a type='button' href='$detail_route' class='btn btn-primary btn-circle btn-sm' title='view item'><i class='fas fa-eye'></i></a> <a type='button' href='$edit_route' class='btn btn-info btn-circle btn-sm' title='edit item'><i class='fas fa-edit'></i></a> <a type='button' href='#'  $del_func  class='btn btn-danger btn-circle btn-sm  delete-btn' data-route='$delete_route'  title='delete restaurant'><i class='far fa-trash-alt'></i></a>";


                })
                ->rawColumns(['active', 'action'])
                ->make(true);

        }

        return view('admin.food_item.index');

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
        if (!$request->restaurant) {

            flash('Invalid Url')->error();
            return redirect()->route('restaurant.index');


        }

        $restaurant = Restaurant::findOrFail($request->restaurant);


        return view('admin.food_item.create')->with(['foodSections' => $restaurant->foodSections()->get(), 'foodCategories' => FoodCategory::all(), 'restaurant' => $restaurant]);

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

        $form_data = json_decode($request->form_data);
        $mandatoryVariations = json_decode($request->mandatoryVariations);
        $foodItem = new FoodItem();
        $foodItem->description = $form_data->description;
        $foodItem->food_type = $form_data->food_type;
        $foodItem->menu_section_id = $form_data->menu_section_id;
        $foodItem->name = $form_data->name;
        $foodItem->price = $form_data->price;
        
        $foodItem->restaurant_id = $form_data->restaurant_id;
        $foodItem->image = prospiral_store_file($request->image, 'images/restaurants/food_items');
        $foodItem->save();
  
        $foodItem->storeVariations($mandatoryVariations);


        flash('Food Item Added Successfully')->success();
        return response()->json(array('error' => false, 'message' => 'item stored successfully'));

    }

    /**
     * Display the specified resource.
     *
     * @param \App\FoodItem $foodItem
     * @return \Illuminate\Http\Response
     */
    public function show(FoodItem $foodItem)
    {
        return view('admin.food_item.show', compact('foodItem'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param \App\FoodItem $foodItem
     * @return \Illuminate\Http\Response
     */
    public function edit(FoodItem $foodItem)
    {
        return view('admin.food_item.edit')->with(['foodItem' => $foodItem, 'variations' => FoodVariation::collection($foodItem->variations)]);

    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param \App\FoodItem $foodItem
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, FoodItem $foodItem)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param \App\FoodItem $foodItem
     * @return \Illuminate\Http\Response
     */
    public function destroy(FoodItem $foodItem)
    {
        try {
            $foodItem->delete();
            flash('Food item Deleted Successfully')->warning();
            return redirect()->back();
        } catch (\Exception $exception) {
            flash('whoops, something went wrong')->error();
            return redirect()->back();
        }
    }


    function updateItem(Request $request, FoodItem $foodItem)
    {
        $form_data = json_decode($request->form_data);
        $mandatoryVariations = json_decode($request->mandatoryVariations);

        $foodItem->description = $form_data->description;

        $foodItem->food_type = $form_data->food_type;
        $foodItem->menu_section_id = $form_data->menu_section_id;
        $foodItem->name = $form_data->name;
        $foodItem->price = $form_data->price;
        $foodItem->restaurant_id = $form_data->restaurant_id;
        if ($request->hasFile('image'))
            $foodItem->image = prospiral_store_file($request->image, 'images/restaurants/food_items');
        $foodItem->save();
        $foodItem->variations()->delete();
        $foodItem->storeVariations($mandatoryVariations);


        flash('Food Item Updated  Successfully')->success();
        return response()->json(array('error' => false, 'message' => 'item Updated successfully'));
    }


    public function activeStatus(Request $request)
    {

        $item = FoodItem::find($request->id);
        $item->setActiveStatus($request->status);
        return response()->json(array('error' => $request->all()));
    }


}
