<?php

namespace App\Http\Controllers;

use App\Cuisine;
use App\Mail\MerchantCreated;
use App\Restaurant;
use App\RestCategory;
use App\User;
use QrCode;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;
use phpDocumentor\Reflection\DocBlock\Tags\Uses;
use Yajra\DataTables\DataTables;

class restaurantController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index()
    {
        if (request()->ajax()) {
            return DataTables::of(Restaurant::select('id', 'name', 'phone', 'address', 'featured','qr_link')->orderBy('id', 'desc')->get())->addColumn('featured', function ($restaurant) {


                $checked = $restaurant->featured ? 'checked' : '';

                return "<div class='custom-control custom-switch'  >
                <input type='checkbox' class='custom-control-input feature-restaurant' data-id='$restaurant->id'  $checked id='item-switch$restaurant->id'  >
                 <label class='custom-control-label' for='item-switch$restaurant->id' ></label >
                    </div > ";
            })
            ->addColumn('qrcode', function ($restaurant) {


                $qrlink = route('generate.qr') . "?restaurant=$restaurant->id";
                $id = $restaurant->id;
                return "<a type='button' href='$qrlink' target='_blank' class='btn btn-success btn-sm' title='view QR'><i class='fa fa-eye'></i> View QR</a> <a type='button' id='$id' onclick='addqrcode(this.id)' class='btn btn-warning btn-sm' title='generate QR'><i class='fa fa-plus'></i> Generate new QR</a>";

                })
                ->addColumn('action', function ($restaurant) {
                    $route = route('food-item.create') . "?restaurant=$restaurant->id";
                    $id = $restaurant->id;
                    $edit_route = route('restaurant.edit', ['restaurant' => $restaurant->id]);
                    $delete_route = route('restaurant.destroy', ['restaurant' => $restaurant->id]);
                    $view_route = route('view.restaurant',$restaurant->name);
                    $del_func = "onclick = deletenow('$delete_route')";
                    return "<a type='button' href='$route' class='btn btn-success btn-sm font-weight-bold' title='add food item'><i class='fas fa-plus'></i> Add Food Item</a> <a type='button' href='$edit_route' class='btn btn-info btn-circle btn-sm' title='edit restaurant'><i class='fas fa-edit'></i></a> <a type='button' href='#'  $del_func  class='btn btn-danger btn-circle btn-sm  delete-btn' data-route='$delete_route'  title='delete restaurant'><i class='far fa-trash-alt'></i></a>
                     <a type='button' href='$view_route'  class='btn btn-primary btn-circle btn-sm '  title='view restaurant'><i class='far fa-eye-alt'></i></a>";
                })->rawColumns(['featured', 'action','qrcode'])
                ->make(true);

        }
        return view('admin.restaurant.index');
    }

    public function getRows()
    {
        return DataTables::of(Restaurant::orderBy('id', 'desc')->get())->make(true);

    }


    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        return view('admin.restaurant.create')->with([
            'categories' => RestCategory::all(),
            'cuisines' => Cuisine::all()
        ]);

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return Response
     */
    public function store(Request $request)
    {


        $validator = Validator::make($request->all(), [
            'merchantEmail' => 'unique:users,email',
        ]);

        if ($validator->fails()) {
            flash('Merchant Email is already in use')->error();

            return redirect()->back();

        }


        $request_data = $request->all();
        //  dd($request_data);
        $restaurant = Restaurant::create($request_data);

        if ($request->hasFile('image'))
            $restaurant->image = prospiral_store_file($request->image, "images/restaurant/logos");

        if ($request->hasFile('header_image'))
            $restaurant->header_image = prospiral_store_file($request->header_image, "images/restaurant/header_images");

        $restaurant->store_acronym();

        $restaurant->save();
        $restaurant->cuisines()->attach($request->cuisines);
        $restaurant->categories()->attach($request->restaurantCategories);

//        $user = new


        try {
            $user = new User();
            $user->name = $request->merchantName;
            $user->email = $request->merchantEmail;
            $password = Str::random(8);
            $user->password = bcrypt($password);
            $user->restaurant_id = $restaurant->id;
            $user->save();

            Mail::to($user->email)->send(new MerchantCreated($user, $password));

        } catch (Exception $exception) {
            dd($exception);
        }


        flash('Restaurant Created Successfully');

        return redirect()->back();
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Restaurant $restaurant
     * @return Response
     */
    public function edit(Restaurant $restaurant)
    {
        return view('admin.restaurant.edit')->with([
            'categories' => RestCategory::all(),
            'cuisines' => Cuisine::all(),
            'restaurant' => $restaurant
        ]);

    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param Restaurant $restaurant
     * @return Response
     */
    public function update(Request $request, Restaurant $restaurant)
    {

        if ($request->merchantEmail != $restaurant->merchant->email) {
            $validator = Validator::make($request->all(), [
                'merchantEmail' => 'unique:users,email',
            ]);

            if ($validator->fails()) {
                flash('Merchant Email is already in use')->error();

                return redirect()->back();

            }
        }


        $request_data = $request->all();

        $restaurant->update($request_data);

        if ($request->hasFile('image'))
            $restaurant->image = prospiral_store_file($request->image, "images/restaurant/logos");

        if ($request->hasFile('header_image'))
            $restaurant->header_image = prospiral_store_file($request->header_image, "images/restaurant/header_images");

        $restaurant->save();

        $restaurant->cuisines()->detach();
        $restaurant->categories()->detach();

        $restaurant->cuisines()->attach($request->cuisines);
        $restaurant->categories()->attach($request->restaurantCategories);

//        $user = new

        if ($request->merchantEmail != $restaurant->merchant->email) {
            try {
                $user = $restaurant->merchant;
                $user->name = $request->merchantName;
                $user->email = $request->merchantEmail;
                $password = Str::random(8);
                $user->password = bcrypt($password);
                $user->restaurant_id = $restaurant->id;
                $user->save();

//                Mail::to($user->email)->send(new MerchantCreated($user, $password));

            } catch (Exception $exception) {
                dd($exception);
            }
        }

        flash('Restaurant Updated  Successfully');

        return redirect()->back();


    }

    /**
     * Remove the specified resource from storage.
     *
     * @param Restaurant $restaurant
     * @return Response
     * @throws Exception
     */
    public function destroy(Restaurant $restaurant)
    {
        $restaurant->foodItems()->delete();
        $restaurant->delete();
        flash('Restaurant Deleted Successfully')->error();
        return redirect()->back();
    }


    public function setFeature(Request $request)
    {

        $restaurant = Restaurant::find($request->id);
        $restaurant->featured = $request->status;
        $restaurant->save();
        return response()->json(array('error' => $request->all()));
    }


    public function generateQR(Request $request)
    {

        $restaurant = Restaurant::find($request->restaurant);
        if($restaurant->qr_link == "" || $restaurant->qr_link == null)
        {
          $link = route('view.restaurant',$restaurant->name);
       return QrCode::size(300)->generate($link);
        }
        else{
          return QrCode::size(300)->generate($restaurant->qr_link);
        }
    }


    public function createQR(Request $request)
    {

        $restaurant = Restaurant::find($request->restaurant_id);
        $restaurant->qr_link = $request->link;
        $restaurant->save();
        return redirect()->back();
    }
    
    
     public function generateQRwifi(Request $request)
    {

        $restaurant = Restaurant::find($request->restaurant);
        if($restaurant)
        {
          $wifiname = $restaurant->wifi_name;
          $wifipassword = $restaurant->wifi_password;
            return QrCode::size(300)->generate("Wifi Name:".$wifiname." | Wifi Password:".$wifipassword);
        }
        return redirect()->back();
    }


}
