<?php

namespace App;

use App\Mail\orderPlaced;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Mail;

class Order extends Model
{

    protected $fillable = ['customer_id', 'restaurant_id', 'address_id', 'phone', 'status', 'payment_method', 'lng', 'lat', 'additional_address', 'order_time', 'payable_amount', 'note', 'order_type', 'table_no'];

    public function restaurant()
    {
        return $this->belongsTo(Restaurant::class, 'restaurant_id');
    }


    public function customer()
    {
        return $this->belongsTo(Customer::class, 'customer_id');
    }

    public function address()
    {
        return $this->belongsTo(Address::class, 'address_id');
    }


    public function storeOrderNo()
    {

        $order_no = str_pad($this->id, 5, "0", STR_PAD_LEFT);  //00002
        $order_no = $this->restaurant->acronym . "-" . $order_no;
        $this->order_no = $order_no;
        $this->save();

    }

    public function newOrderNotification()
    {

        $config = array('title' => 'New Order Received', 'body' => "You have received new order number {{$this->order_no}}", 'redirect' => route('merchant.orders.index'), 'type' => 'order');
        $this->restaurant->merchant->first()->sendNotification($config);
        Mail::to($this->customer->email)->send(new orderPlaced($this));

        return true;


    }


    public function scopeCurrent($query)
    {
        $statuses = ['PENDING', 'ACCEPTED'];
        return $query->whereIn('status', $statuses);
    }

    public function scopePast($query)
    {
        $statuses = ['CANCELED', 'COMPLETED'];

        return $query->whereIn('status', $statuses);

    }


    public function items()
    {
        return $this->hasMany(OrderedItem::class, 'order_id');
    }


//    store items
    public function storeItems($items)
    {

        foreach ($items as $item) {

            $orderedItem = new OrderedItem();
            $orderedItem->order_id = $this->id;
            $orderedItem->item_id = $item['id'];
            $orderedItem->quantity = $item['quantity'];
            $orderedItem->price = $item['total_price'];
            $orderedItem->custom = 0;
            $orderedItem->notes = null;

            $orderedItem->save();

            $orderedItem->storeVariations($item);

        }

        return $this;

    }


    public function setStatus($status)
    {
        if ($status == "ACCEPTED")
            $this->status = "ACCEPTED";

        if ($status == "CANCELED")
            $this->status = "CANCELED";

        if ($status == "COMPLETED") {
            $this->status = "COMPLETED";
            $this->completed_at = Carbon::now()->toDateTimeString();
        }
        return $this->save();


    }


    public function scopeFilterHours($query, $hours = 24)
    {

        $formatted_date = Carbon::now()->subHours($hours)->format('Y-m-d H:i:s');


        return $query->where('created_at', '>', $formatted_date);

    }


}
